@@ -308,7 +308,7 @@ def main():  # noqa: C901  # pylint: disable=too-many-branches,too-many-statemen
                 weConnect = weconnect.WeConnect(username=username, password=password, spin=spin, updateAfterLogin=False,
                                                 updateCapabilities=mqttCLient.updateCapabilities, updatePictures=mqttCLient.updatePictures,
                                                 maxAgePictures=args.pictureCache, selective=mqttCLient.selective,
-                                                forceReloginAfter=21600)
+                                                forceReloginAfter=21600, timeout=180)
                 mqttCLient.connectWeConnect(weConnect)
                 break
             except exceptions.ConnectionError as e:
@@ -604,6 +604,10 @@ class WeConnectMQTTClient(paho.mqtt.client.Client):  # pylint: disable=too-many-
                 if topic not in self.topics:
                     self.addTopic(topic + '_writetopic', writeable=True)
 
+            # Subscribe again to all writeable topics after a reconnect
+            for writeableTopic in self.writeableTopics:
+                self.subscribe(writeableTopic, qos=1)
+
             self.setConnected()
 
             if self.updateOnConnect:
@@ -624,7 +628,7 @@ class WeConnectMQTTClient(paho.mqtt.client.Client):  # pylint: disable=too-many-
             print('Could not connect: %d', rc, file=sys.stderr)
             sys.exit(1)
 
-    def on_connect_callback_v5(self, mqttc, obj, flags, reasonCode, properties):  # noqa: C901
+    def on_connect_callback_v5(self, mqttc, obj, flags, reasonCode, properties):  # noqa: C901  # pylint: disable=too-many-branches
         del mqttc  # unused
         del obj  # unused
         del flags  # unused
@@ -645,6 +649,10 @@ class WeConnectMQTTClient(paho.mqtt.client.Client):  # pylint: disable=too-many-
                 if topic not in self.topics:
                     self.addTopic(topic + '_writetopic', writeable=True)
 
+            # Subscribe again to all writeable topics after a reconnect
+            for writeableTopic in self.writeableTopics:
+                self.subscribe(writeableTopic, qos=1)
+
             self.setConnected()
 
             if self.updateOnConnect:
@@ -716,7 +724,7 @@ class WeConnectMQTTClient(paho.mqtt.client.Client):  # pylint: disable=too-many-
                 finally:
                     time.sleep(10)
 
-    def on_disconnect_callback_v5(self, client, userdata, reasonCode, properties):  # noqa: C901
+    def on_disconnect_callback_v5(self, client, userdata, reasonCode, properties):  # noqa: C901  # pylint: disable=too-many-branches
         del client
         del properties
 
